import { __assign } from './../../external/tslib/tslib.es6.js';
import { IMask } from '@highlight-ui/input';
import subDays from './../../external/date-fns/esm/subDays/index.js';
import './../../external/flatpickr/dist/l10n/de.js';
import './../../external/flatpickr/dist/l10n/default.js';
import './../../external/flatpickr/dist/l10n/es.js';
import './../../external/flatpickr/dist/l10n/fr.js';
import './../../external/flatpickr/dist/l10n/nl.js';
import './../../external/flatpickr/dist/l10n/it.js';
import head from 'lodash/head';
import set from 'lodash/set';
import isValid from './../../external/date-fns/esm/isValid/index.js';
import formatDate from './../../external/date-fns/esm/fp/format/index.js';
import parseDate from './../../external/date-fns/esm/fp/parse/index.js';
import { _ as _default } from '../../_virtual/default.js';
import { d as de } from '../../_virtual/de.js';
import { e as es } from '../../_virtual/es.js';
import { f as fr } from '../../_virtual/fr.js';
import { n as nl } from '../../_virtual/nl.js';
import { i as it } from '../../_virtual/it.js';

var mapWeekDays = function (locale) {
  return set(locale, 'weekdays.shorthand', locale.weekdays.shorthand.map(head));
};
/**
 * Validates a string that represents a date written in a specific format
 * against the list of disabled dates.
 * An incomplete string is considered valid.
 * It is highly specific for the `imask` date validation use-case.
 * @param inputValue string that represents a date
 * @param dateFormat string that describes the date format for the `inputValue`
 * @param dateAsStringRegExp used to test the string for completeness
 * @param disabledDates a list of `Date` objects, representing the disabled dates
 */


var isIMaskValueValidDate = function (inputValue, dateFormat, dateAsStringRegExp, disabledDates) {
  // user started typing, not finished yet
  if (inputValue.length < dateFormat.length) {
    return true;
  } // user has removed a digit


  if (/_/g.test(inputValue)) {
    return true;
  } // user typed in the date, check if the format is right


  if (inputValue.length === dateFormat.length && !dateAsStringRegExp.test(inputValue)) {
    return false;
  } // check if the entered string is a correct date, return before checking the disabled dates


  if (!isValid(parseDate(new Date(), dateFormat, inputValue))) {
    return false;
  }

  if (disabledDates) {
    // user typed in the correct date, convert each disabled date into a string and check the strings
    if (disabledDates.some(function (dd) {
      return formatDate(dateFormat, dd) === inputValue;
    })) {
      return false;
    }
  }

  return true;
};

var hourMask = function (value) {
  if (Number.isNaN(value)) return false;
  if (value.split('').some(function (char) {
    return Number.isNaN(parseInt(char, 10));
  })) return false;
  var parsedValue = parseInt(value, 10);
  return value.length < 3 && parsedValue >= 0 && parsedValue <= 23;
};

var getDefaultTimeConfig = function () {
  return {
    iconName: 'clock',
    placeholder: 'HH:MM',
    parseFormat: 'HH:mm',
    maskOptions: {
      mask: 'HH:MM',
      blocks: {
        HH: {
          mask: hourMask
        },
        MM: {
          mask: new IMask.Range({
            mask: '0',
            from: 0,
            to: 59
          })
        }
      }
    }
  };
};

var getTimeConfigByLocale = function (locale) {
  var configMapping = {
    'de-DE': getDefaultTimeConfig,
    'en-GB': getDefaultTimeConfig,
    'es-ES': getDefaultTimeConfig,
    'fr-FR': getDefaultTimeConfig,
    'nl-NL': getDefaultTimeConfig,
    'it-IT': getDefaultTimeConfig
  };
  return configMapping[locale];
};

var getDateConfigByLocale = function (locale) {
  var maskOptions = function (_a) {
    var minDate = _a.minDate,
        maxDate = _a.maxDate,
        disabledDates = _a.disabledDates;
    return __assign(__assign(__assign({
      mask: Date,
      pattern: 'dd`/mm`/yyyy',
      blocks: {
        dd: {
          mask: IMask.Range,
          from: 1,
          to: 31,
          maxLength: 2
        },
        mm: {
          mask: IMask.Range,
          from: 1,
          to: 12,
          maxLength: 2
        },
        yyyy: {
          mask: IMask.Range,
          from: 1000,
          to: 9999,
          maxLength: 4
        }
      },
      validate: function (value) {
        return isIMaskValueValidDate(value, 'dd/MM/yyyy', /\d{2}\/\d{2}\/\d{4}/, disabledDates);
      },
      format: formatDate('dd/MM/yyyy'),
      parse: parseDate(new Date(), 'dd/MM/yyyy')
    }, minDate ? {
      min: subDays(minDate, 1)
    } : {}), maxDate ? {
      max: maxDate
    } : {}), {
      lazy: true,
      autofix: true
    });
  };

  var configMapping = {
    'en-GB': function (_a) {
      var _b = _a === void 0 ? {} : _a,
          minDate = _b.minDate,
          maxDate = _b.maxDate,
          disabledDates = _b.disabledDates;

      return {
        iconName: 'calendar-alt',
        placeholder: 'DD/MM/YYYY',
        parseFormat: 'dd/MM/yyyy',
        flatPickrFormat: 'd/m/Y',
        flatPickrLocale: set(mapWeekDays(_default.exports.english), 'firstDayOfWeek', 1),
        maskOptions: maskOptions({
          minDate: minDate,
          maxDate: maxDate,
          disabledDates: disabledDates
        })
      };
    },
    'de-DE': function (_a) {
      var _b = _a === void 0 ? {} : _a,
          minDate = _b.minDate,
          maxDate = _b.maxDate,
          disabledDates = _b.disabledDates;

      return {
        iconName: 'calendar-alt',
        placeholder: 'TT/MM/JJJJ',
        parseFormat: 'dd/MM/yyyy',
        flatPickrFormat: 'd/m/Y',
        flatPickrLocale: mapWeekDays(de.exports.German),
        maskOptions: maskOptions({
          minDate: minDate,
          maxDate: maxDate,
          disabledDates: disabledDates
        })
      };
    },
    'es-ES': function (_a) {
      var _b = _a === void 0 ? {} : _a,
          minDate = _b.minDate,
          maxDate = _b.maxDate,
          disabledDates = _b.disabledDates;

      return {
        iconName: 'calendar-alt',
        placeholder: 'DD/MM/AAAA',
        parseFormat: 'dd/MM/yyyy',
        flatPickrFormat: 'd/m/Y',
        flatPickrLocale: mapWeekDays(es.exports.Spanish),
        maskOptions: maskOptions({
          minDate: minDate,
          maxDate: maxDate,
          disabledDates: disabledDates
        })
      };
    },
    'fr-FR': function (_a) {
      var _b = _a === void 0 ? {} : _a,
          minDate = _b.minDate,
          maxDate = _b.maxDate,
          disabledDates = _b.disabledDates;

      return {
        iconName: 'calendar-alt',
        placeholder: 'JJ/MM/AAAA',
        parseFormat: 'dd/MM/yyyy',
        flatPickrFormat: 'd/m/Y',
        flatPickrLocale: mapWeekDays(fr.exports.French),
        maskOptions: maskOptions({
          minDate: minDate,
          maxDate: maxDate,
          disabledDates: disabledDates
        })
      };
    },
    'nl-NL': function (_a) {
      var _b = _a === void 0 ? {} : _a,
          minDate = _b.minDate,
          maxDate = _b.maxDate,
          disabledDates = _b.disabledDates;

      return {
        iconName: 'calendar-alt',
        placeholder: 'DD/MM/JJJJ',
        parseFormat: 'dd/MM/yyyy',
        flatPickrFormat: 'd/m/Y',
        flatPickrLocale: mapWeekDays(nl.exports.Dutch),
        maskOptions: maskOptions({
          minDate: minDate,
          maxDate: maxDate,
          disabledDates: disabledDates
        })
      };
    },
    'it-IT': function (_a) {
      var _b = _a === void 0 ? {} : _a,
          minDate = _b.minDate,
          maxDate = _b.maxDate,
          disabledDates = _b.disabledDates;

      return {
        iconName: 'calendar-alt',
        placeholder: 'GG/MM/AAAA',
        parseFormat: 'dd/MM/yyyy',
        flatPickrFormat: 'd/m/Y',
        flatPickrLocale: mapWeekDays(it.exports.Italian),
        maskOptions: maskOptions({
          minDate: minDate,
          maxDate: maxDate,
          disabledDates: disabledDates
        })
      };
    }
  };
  return configMapping[locale];
};

export { getDateConfigByLocale, getTimeConfigByLocale, hourMask, isIMaskValueValidDate };
//# sourceMappingURL=date-time-config.js.map
